bb004 test

# Pulp Fiction

There was an accitental killing of a man. The man was shot in the head - so the car and both, Vincent and Jules, are spleatted with blood. This must be brought back to order. The one who helps here is Mr. Wulf.

## Auto saubermachen

Description
  Auf den ersten Blick muss das Auto normal aussehen.
Rationale

  Aktuell ist das Auto voller Blut.

Depends on:
  CreateOrder
Dependent
  CleanUpSeats, DetergentForCar
Id
  CleanUpCar
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Autositzte reinigen

Description
  Die Autositzte müssen gereinigt werden.
Depends on:
  CleanUpCar
Dependent
  CoverWithBlankets, RoughlyCleanUpSeats
Id
  CleanUpSeats
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  detailable

## Vincent und Jules reinigen

Description
  Vincent und Jules müssen gereinigt werden.
Rationale

  Beide sind über und über mit Blut bedeckt.

Depends on:
  CreateOrder
Dependent
  SoapAndColdWater, TakeCareOfClothing, TakeOff
Id
  CleanUpVicentAndJules
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Leiche in den Kofferraum

Description
  Die Leiche muss in den Kofferraum.
Rationale

  Das fahrende Auto darf kein Aufsehen erregen - so kann der Tote transportiert werden.

Depends on:
  DeadManDisapper
Id
  CorpseInTrunk
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Mit Decken zudecken

Description
  Die Autositze müssen mit Decken abgedeckt werden.
Rationale

  Es ist nicht möglich, die Sitze vollständig zu reinigen.

Depends on:
  CleanUpSeats, RoughlyCleanUpSeats
Id
  CoverWithBlankets
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Ordnung widerherstellen

Description
  The unglückliche Unfall, der einen Mann getötet hat, muss versteckt werden.
Rationale

  Es gibt einige dreckige und mit Blut verschmierte Sachen, die gereinigt werden müssen.

Note
  Sie haben nur 40 Minuten für alles.
Dependent
  CleanUpCar, CleanUpVicentAndJules, DeadManDisapper
Id
  CreateOrder
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Toter Mann muss verschwinden

Description
  Der tote Mann muss verschwinden.
Rationale

  Der bei einem Unfall zu Tode gekommene muss verschwinden.

Depends on:
  CreateOrder
Dependent
  CorpseInTrunk
Id
  DeadManDisapper
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  VincentAndJules
Status
  not done
Class
  detailable

## Putzmittel für das Auto

Description
  Das Auto muss mit Putzmitteln gereinigt werden.
Rationale

  Das Auto ist voller Blut - daher ist Putzmittel notwendig es zu reinigen.

Note
  Die Putzmittel stehen in der Küche unter der Spüle.
Depends on:
  CleanUpCar
Id
  DetergentForCar
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Sitze grob reinigen

Description
  Die Autositzte müssen grob gereinigt werden.
Rationale

  Es ist nicht möglich sie vollständig zu reinigen - es werden noch Decken hinübergelegt.

Depends on:
  CleanUpSeats
Dependent
  CoverWithBlankets
Id
  RoughlyCleanUpSeats
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Seife und kaltes Wasser

Description
  Vincent und Jules müssen sich mit Seife und kaltem Wasser vom Blut reinigen.
Rationale

  Sie sind blutig.

Depends on:
  CleanUpVicentAndJules, TakeOff
Id
  SoapAndColdWater
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Auf Kleidung achten

Description
  Auf Vincent und Jules' Kleidung muss geachtet werden.
Rationale

  Die Kleidung ist blutig - Otto der Müllmann wird sich weigern dies einzusammeln.

Depends on:
  CleanUpVicentAndJules, TakeOff
Id
  TakeCareOfClothing
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable

## Ausziehen

Description
  Vincent und Jules müssen ihre Kleider ausziehen.
Rationale

  Sie sind blutig.

Note
  Wulf: 'Bis auf den nackten Arsch'.
Depends on:
  CleanUpVicentAndJules
Dependent
  SoapAndColdWater, TakeCareOfClothing
Id
  TakeOff
Priority
  10.00
Owner
  executive
Invented on
  1994-04-04
Invented by
  Wulf
Status
  not done
Class
  implementable